pub struct DeriveWebSocketSubscriptionHandle { /* private fields */ }Expand description
Cloneable command handle for Derive public market data subscriptions.
Implementations
Sourceimpl DeriveWebSocketSubscriptionHandle
impl DeriveWebSocketSubscriptionHandle
Sourcepub async fn subscribe_ticker(
&self,
instrument_name: &str,
interval: &str,
) -> Result<()>
pub async fn subscribe_ticker( &self, instrument_name: &str, interval: &str, ) -> Result<()>
Subscribes to ticker_slim.{instrument_name}.{interval}.
Errors
Propagates JSON-RPC errors raised by the venue and transport-level failures.
Sourcepub async fn unsubscribe_ticker(
&self,
instrument_name: &str,
interval: &str,
) -> Result<()>
pub async fn unsubscribe_ticker( &self, instrument_name: &str, interval: &str, ) -> Result<()>
Unsubscribes from ticker_slim.{instrument_name}.{interval}.
Errors
Propagates JSON-RPC errors raised by the venue and transport-level failures.
Sourcepub async fn subscribe_orderbook(
&self,
instrument_name: &str,
group: &str,
depth: &str,
) -> Result<()>
pub async fn subscribe_orderbook( &self, instrument_name: &str, group: &str, depth: &str, ) -> Result<()>
Subscribes to orderbook.{instrument_name}.{group}.{depth}.
Errors
Propagates JSON-RPC errors raised by the venue and transport-level failures.
Sourcepub async fn unsubscribe_orderbook(
&self,
instrument_name: &str,
group: &str,
depth: &str,
) -> Result<()>
pub async fn unsubscribe_orderbook( &self, instrument_name: &str, group: &str, depth: &str, ) -> Result<()>
Unsubscribes from orderbook.{instrument_name}.{group}.{depth}.
Errors
Propagates JSON-RPC errors raised by the venue and transport-level failures.
Sourcepub async fn subscribe_trades(
&self,
instrument_type: &str,
currency: &str,
) -> Result<()>
pub async fn subscribe_trades( &self, instrument_type: &str, currency: &str, ) -> Result<()>
Subscribes to trades.{instrument_type}.{currency}.
Errors
Propagates JSON-RPC errors raised by the venue and transport-level failures.
Sourcepub async fn unsubscribe_trades(
&self,
instrument_type: &str,
currency: &str,
) -> Result<()>
pub async fn unsubscribe_trades( &self, instrument_type: &str, currency: &str, ) -> Result<()>
Unsubscribes from trades.{instrument_type}.{currency}.
Errors
Propagates JSON-RPC errors raised by the venue and transport-level failures.
Sourcepub async fn subscribe_channels<C>(&self, channels: Vec<C>) -> Result<()>where
C: Into<DeriveWsChannel>,
pub async fn subscribe_channels<C>(&self, channels: Vec<C>) -> Result<()>where
C: Into<DeriveWsChannel>,
Subscribes to multiple channel topics in a single subscribe frame.
Errors
Propagates JSON-RPC errors raised by the venue and transport-level failures.
Sourcepub async fn unsubscribe_channels<C>(&self, channels: Vec<C>) -> Result<()>where
C: Into<DeriveWsChannel>,
pub async fn unsubscribe_channels<C>(&self, channels: Vec<C>) -> Result<()>where
C: Into<DeriveWsChannel>,
Unsubscribes from multiple channel topics in a single
unsubscribe frame.
Errors
Propagates JSON-RPC errors raised by the venue and transport-level failures.